# GAN API

The {class}`TTS.vocoder.models.gan.GAN` provides an easy way to implementing new GAN based models. You just need
to define the model architectures for the generator and the discriminator networks and give them to the `GAN` class
to do its ✨️.


## GAN
```{eval-rst}
.. autoclass:: TTS.vocoder.models.gan.GAN
    :members:
```
